@@ -79,6 +79,7 @@ class hgboost:
         if (max_eval is None) or (max_eval <= 0): max_eval=1
         if top_cv_evals is None: max_eval=0
         if (test_size is None) or (test_size <= 0): raise ValueError('[hgboost] >Error: test_size must be >0 and not [None] Note: the final model is learned on the entire dataset. [test_size] may help you getting a more robust model.')
+        if (val_size is not None) and (val_size<=0): val_size=None
 
         self.max_eval=max_eval
         self.top_cv_evals=top_cv_evals
@@ -124,6 +125,10 @@ class hgboost:
         # Check input data
         X, y, self.pos_label=_check_input(X, y, pos_label, self.method, verbose=self.verbose)
 
+        # Recaculate test size. This should be the percentage of the total dataset after removing the validation set.
+        if (self.val_size is not None) and (self.val_size > 0):
+            self.test_size = np.round((self.test_size * X.shape[0]) / (X.shape[0] - (self.val_size * X.shape[0])), 2)
+
         # Print to screen
         if self.verbose>=3:
             print('[hgboost] >method: %s' %(self.method))
@@ -174,6 +179,7 @@ class hgboost:
         eval_metric : str, (default : 'rmse').
             Evaluation metric for the regressor model.
                 * 'rmse': root mean squared error.
+                * 'mse': mean squared error.
                 * 'mae': mean absolute error.
         greater_is_better : bool (default : False).
             If a loss, the output of the python function is negated by the scorer object, conforming to the cross validation convention that scorers return higher values for better models.
@@ -209,8 +215,9 @@ class hgboost:
             Response variable.
         eval_metric : str, (default : 'rmse').
             Evaluation metric for the regressor model.
-            * 'rmse': root mean squared error.
-            * 'mae': mean absolute error.
+                * 'rmse': root mean squared error.
+                * 'mse': mean squared error.
+                * 'mae': mean absolute error.
         greater_is_better : bool (default : False).
             If a loss, the output of the python function is negated by the scorer object, conforming to the cross validation convention that scorers return higher values for better models.
         params : dict, (default : 'default').
@@ -246,6 +253,7 @@ class hgboost:
         eval_metric : str, (default : 'rmse').
             Evaluation metric for the regressor model.
                 * 'rmse': root mean squared error.
+                * 'mse': mean squared error.
                 * 'mae': mean absolute error.
         greater_is_better : bool (default : False).
             If a loss, the output of the python function is negated by the scorer object, conforming to the cross validation convention that scorers return higher values for better models.
@@ -522,6 +530,7 @@ class hgboost:
                 self.X, self.X_val, self.y, self.y_val = train_test_split(X, y, test_size=self.val_size, random_state=self.random_state, shuffle=True, stratify=y)
             elif '_reg' in self.method:
                 self.X, self.X_val, self.y, self.y_val = train_test_split(X, y, test_size=self.val_size, random_state=self.random_state, shuffle=True)
+            if self.verbose>=3: print('[hgboost] >Validation set: %s ' %(str(self.X_val.shape)))
         else:
             self.X = X
             self.y = y
@@ -551,7 +560,6 @@ class hgboost:
             * val_results: Results on independent validation dataset.
 
         """
-        if self.verbose>=3: print('[hgboost] >Hyperparameter optimization..')
         # Import the desired model-function for the classification/regression
         disable = (False if (self.verbose<3) else True)
         fn = getattr(self, self.method)
@@ -563,6 +571,10 @@ class hgboost:
         elif '_reg' in self.method:
             self.X_train, self.X_test, self.y_train, self.y_test = train_test_split(self.X, self.y, test_size=self.test_size, random_state=self.random_state, shuffle=True)
 
+        if self.verbose>=3: print('[hgboost] >Train-set: %s ' %(str(self.X_train.shape)))
+        if self.verbose>=3: print('[hgboost] >Test-set: %s ' %(str(self.X_test.shape)))
+        if self.verbose>=3: print('[hgboost] >Hyperparameter optimization..')
+
         # Hyperoptimization to find best performing model. Set the trials which is the object where all the HPopt results are stored.
         trials=Trials()
         best_params = fmin(fn=fn, space=self.space, algo=self.algo, max_evals=self.max_eval, trials=trials, show_progressbar=disable)
@@ -832,8 +844,10 @@ class hgboost:
         elif '_reg' in self.method:
             # Regression
             # loss = space['loss_func'](y_test, y_pred)
-            if self.eval_metric=='rmse':
-                loss = mean_squared_error(y_test, y_pred)
+            if self.eval_metric=='mse':
+                loss = mean_squared_error(y_test, y_pred, squared=True)
+            elif self.eval_metric=='rmse':
+                loss = mean_squared_error(y_test, y_pred, squared=False)
             elif self.eval_metric=='mae':
                 loss = mean_absolute_error(y_test, y_pred)
             else:
@@ -1582,6 +1596,8 @@ def _check_eval_metric(method, eval_metric, greater_is_better, verbose=3):
             greater_is_better=True
         elif (eval_metric == 'rmse'):
             greater_is_better=False
+        elif (eval_metric == 'mse'):
+            greater_is_better=False
         elif (eval_metric == 'mae'):
             greater_is_better=False
         else:
